This directory contains example notebooks explaining core RAIL functionality.

- [00_Useful_Utilities.ipynb](https://rail-hub.readthedocs.io/projects/rail-notebooks/en/latest/rendered/core_examples/00_Useful_Utilities.html) demonstrates a variety of ways that users may interact with data in RAIL.

- [03_Hyperbolic_Magnitude.ipynb](https://rail-hub.readthedocs.io/projects/rail-notebooks/en/latest/rendered/core_examples/03_Hyperbolic_Magnitude.html) provides an example of how to convert classical to hyperbolical magnitudes using the pipeline stages HyperbolicSmoothing and HyperbolicMagnitudes in the rail.core module

- [04_Iterate_Tabular_Data.ipynb](https://rail-hub.readthedocs.io/projects/rail-notebooks/en/latest/rendered/core_examples/04_Iterate_Tabular_Data.html) explains how to iterate over hdf5 data files interactively.

- [05_Build_Save_Load_Run_Pipeline.ipynb](https://rail-hub.readthedocs.io/projects/rail-notebooks/en/latest/rendered/core_examples/05_Build_Save_Load_Run_Pipeline.html) explains how to build a RAIL pipeline interactively.

## RAIL v1.0 Notebook
These notebooks explain functionality that does not exist in the latest version of RAIL. 

- [01_FileIO_DataStore.ipynb](https://rail-hub.readthedocs.io/projects/rail-notebooks/en/latest/rendered/core_examples/01_FileIO_DataStore.html) demonstrates a variety of ways that users may interact with data in RAIL.
